@@ -12,6 +12,8 @@ COMPLEX_TYPES = {
         'RecordList',
         'RecordRef',
         'ListOrRecordRef',
+        'SearchColumnStringField',
+        'SearchColumnSelectField',
         'SearchResult',
         'SearchEnumMultiSelectField',
         'SearchStringField',
@@ -60,6 +62,9 @@ COMPLEX_TYPES = {
         'CustomRecordSearchBasic',
         'CustomListSearchBasic',
         'TermSearchBasic',
+        'DepartmentSearchBasic',
+        'ItemSearchBasic', 'ItemSearchRowBasic',
+        'ClassificationSearchBasic',
     ],
 
     # urn:relationships.lists.webservices.netsuite.com
@@ -83,7 +88,10 @@ COMPLEX_TYPES = {
         'Subsidiary', 'SubsidiarySearch',
         'VendorCategory', 'VendorCategorySearch',
         'Term', 'TermSearch',
-        'SalesTaxItem', 'SalesTaxItemSearch'
+        'SalesTaxItem', 'SalesTaxItemSearch',
+        'DepartmentSearch',
+        'ItemSearch', 'ItemSearchAdvanced', 'ItemSearchRow',
+        'ClassificationSearch',
     ],
 
     'ns19': [
@@ -108,6 +116,14 @@ COMPLEX_TYPES = {
         'VendorPaymentApply'
     ],
 
+    'ns23': [
+        'CreditMemo',
+        'CreditMemoApply',
+        'CreditMemoApplyList',
+        'CreditMemoItem',
+        'CreditMemoItemList',
+    ],
+
     # urn:general_2019_2.transactions.webservices.netsuite.com
     # https://webservices.netsuite.com/xsd/transactions/v2019_2_0/general.xsd
     'ns31': [
